@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -115,6 +87,8 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
     private static final String OWN_RIGHTS = "own_rights";
 
+    private static final String OCCURRENCE = "occurrence";
+
     protected static final String _COLUMNS_ID_AND_LAST_MODIFIED = "1,5";
 
     private static final int _MAX_OBJECTS_PER_LIST = 500;
@@ -175,18 +149,21 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
     }
 
     public void confirm(DataObject object, int response) throws AuthenticationFailedException, OXCommunicationException {
-        confirm(object, response, "");
+        confirm(object, response, "", (Number)null);
     }
 
-	public void confirm(DataObject object, int response, String confirmMessage) throws AuthenticationFailedException,
-			OXCommunicationException {
+	public void confirm(DataObject object, int response, String confirmMessage, Number occurrencePosition)
+	    throws AuthenticationFailedException, OXCommunicationException {
 
         if (LOG.isDebugEnabled())
-            LOG.debug(object.getSession() + " Confirming appointment or task " + object.getID());
+            LOG.debug(object.getSession() + " Confirming appointment or task " + object.getSession() + object.getID());
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(CommonConstants.ID, object.getID());
         parameters.put(CommonConstants.FOLDER, object.getParentFolderID());
         parameters.put(CommonConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
+        if (occurrencePosition != null) {
+            parameters.put(OCCURRENCE, String.valueOf(occurrencePosition.intValue()));
+        }
 
         JSONObject requestBody = new JSONObject();
         try {
@@ -216,7 +193,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 	public void confirm(DataObject object, int response, String confirmMessage, String participantId)
 			throws AuthenticationFailedException, OXCommunicationException {
         if (LOG.isDebugEnabled())
-			LOG.debug(object.getSession() + " Confirming appointment " + object.getID() + " for participant: "
+			LOG.debug(object.getSession() + " Confirming appointment " + object.getSession() + object.getID() + " for participant: "
 					+ participantId);
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(CommonConstants.ID, object.getID());
@@ -669,6 +646,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         return readFolderContent(folder, Integer.MAX_VALUE, null).getObjects();
     }
 
+    @Override
     public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
         return readOptimizedFolderContent(folder, limit, filter);
     }
