@@ -1,6 +1,6 @@
 package com.openexchange.usm.mapping.storage.sql.impl;
 
-import gnu.trove.ConcurrentTIntObjectHashMap;
+import gnu.trove.map.hash.ConcurrentTIntObjectHashMap;
 import gnu.trove.map.TIntObjectMap;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
