@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -177,6 +149,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
 
     private boolean _passClientHostHeader = false;
 
+    private boolean _staySignedIn = true;
+
     /**
      * Initializes a new {@link OXJSONAccessImpl}.
      *
@@ -184,10 +158,11 @@ public class OXJSONAccessImpl implements OXJSONAccess {
      * @param maxConnections
      * @param connectionTimeout
      * @param performStaleChecking
+     * @param staySignedIn
      * @param passHostHeaderFromClient
      */
-    public OXJSONAccessImpl(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
-        String error = doActivate(oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes, missingObjectErrorCodes);
+    public OXJSONAccessImpl(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean staySignedIn, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
+        String error = doActivate(oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, staySignedIn, passHostHeaderFromClient, reloginErrorCodes, missingObjectErrorCodes);
         if (error != null) {
             error = "OXJSONAccess not activated, reason: " + error;
             LOG.error(error);
@@ -199,6 +174,12 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     @Override
     public void login(Session session) throws AuthenticationFailedException, OXCommunicationException {
         logout(session, false);
+        if (session.getPassword() == null) {
+            if (LOG.isDebugEnabled()) {
+                LOG.debug(session + "no password given");
+            }
+            throw new AuthenticationFailedException(OXJSONErrorCode.ACCESSIMPL_AUTHENTICATION_FAILED, "no password given", null);
+        }
         try {
             OXConnectionData result = obtainConnectionData(session);
             if (LOG.isDebugEnabled()) {
@@ -275,6 +256,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         method.addParameter("action", "login");
         method.addParameter("name", user);
         method.addParameter("password", password);
+        method.addParameter("staySignedIn", String.valueOf(_staySignedIn));
         for (String header : session.getXRequestHeaders().keySet()) {
             if (CUSTOM_HOST_HEADER.equals(header) && _passClientHostHeader) {
                 method.setRequestHeader(header, session.getXRequestHeaders().get(header));
@@ -431,9 +413,10 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         deactivate("USM OXJSONAccess deactivated");
     }
 
-    private String doActivate(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
+    private String doActivate(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean staySignedIn, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
         _oxJSONBaseURLasString = oxJSONURL;
         _passClientHostHeader = passHostHeaderFromClient;
+        _staySignedIn = staySignedIn;
         try {
             _oxJSONBaseURL = getURLFromString(oxJSONURL);
         } catch (URIException e) {
